; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a line plot with a transparent polygon on it
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "transparent_polygon_plot.pro" and run it like this::
;       IDL> .RUN transparent_polygon_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 7 February 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Transparent_Polygon_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   signal = cgDemoData(1) - 15
   time = cgScaleVector(Findgen(N_Elements(signal)), 0, 6)
   polygon_x = [ 0, 6, 6, 0, 0]
   polygon_y = [-5,-5, 5, 5,-5]
   position = [0.125, 0.125, 0.9, 0.9]
   transparent = 40 ; Percent of transparency.
   
   ; The transparent part of the plot is done in the Z-graphics buffer.
   thisDevice = !D.Name
   Set_Plot, 'Z'
   Device, Set_Resolution=[640,510], Decomposed=1, Set_Pixel_Depth=24
   cgErase
   cgPlot, time, signal, Position=position, XStyle=4, YStyle=4, $
      Color='blu6', PSym=-2, SymColor='tg6'
   background_image = cgSnapshot(Position=position)
   cgColorFill, polygon_x, polygon_y, Color='rose'
   foreground_image = cgSnapshot(Position=position)
   Set_Plot, thisDevice
   
   ; Create a display window
   cgDisplay, 640, 510
   
   ; Display the transparent image.
   alpha = 1 - (transparent/100.)
   cgBlendimage, foreground_image, background_image, ALPHA=alpha, POSITION=position
   
   ; Add the plot annotations.
   cgPlot, time, signal, Position=position, /NoData, XTitle='Time', $
      YTitle='Signal', Title='Example Transparent Polygon Plot', /NoErase
      
   ; Outline the polygon.
   cgPlotS, polygon_x, polygon_y, Color='red'
  
   cgText, 1.25, -14, 'Normal Zone', Alignment=0.5, Color='navy'
   cgArrow, 1.25, -12, 2.125, 0, /Data, Color='navy', /Solid, Thick=3   
       
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Transparent_Polygon_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Transparent_Polygon_Plot', WTitle='Transparent Polygon Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'transparent_polygon_plot.ps'
  Transparent_Polygon_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'transparent_polygon_plot.ps', /PNG, Width=600

END